---
title: Available props
weight: 4
---

These props are available on both the `attachment` and the `collection` component.

| prop name                | Default value                                         | Description                                                                                                                                                                       |
| ------------------------ | ----------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| name                     |                                                       |                                                                                                                                                                                   |
| initialValue             | `[]`                                                  |                                                                                                                                                                                   |
| routePrefix              | `"media-library-pro"`                                 |                                                                                                                                                                                   |
| uploadDomain             |                                                       | Use this if you're uploading your files to a separate (sub)domain, e.g. `files.mydomain.com` (leave out the trailing slash)                                                       |
| validationRules          |                                                       | Refer to the ["validation rules"](#content-validation-rules) section                                                                                                                      |
| validationErrors         |                                                       | The standard Laravel validation error object                                                                                                                                      |
| multiple                 | `false` (always `true` in the `collection` component) | Only exists on the `attachment` components                                                                                                                                        |
| maxItems                 | `1` when `multiple` = `false`, otherwise `undefined   |                                                                                                                                                                                   |
| vapor                    |                                                       | Set to true if you will deploy your application to Vapor, this enables uploading of the files to S3. [Read more](#content-usage-with-laravel-vapor)                                       |
| vaporSignedStorageUrl    | `"vapor/signed-storage-url"`                          |                                                                                                                                                                                   |
| maxSizeForPreviewInBytes | `5242880` (5 MB)                                      | When an image is added, the component will try to generate a local preview for it. This is done on the main thread, and can freeze the component and/or page for very large files |
| sortable                 | `true`                                                | Only exists on the `collection` components. Allows the user to drag images to change their order, this will be reflected by a zero-based `order` attribute in the value           |
| translations             |                                                       | Refer to the ["Translations"](#content-translations) section                                                                                                                              |
| fileTypeHelpText         |                                                       | Override the automatically generated helptext from `validationRules.accept`                                                                                                       |
| setMediaLibrary          |                                                       | Used to set a reference to the MediaLibrary instance, so you can change the internal state of the component.                                                                      |
| beforeUpload             |                                                       | A method that is run right before a temporary upload is started. You can throw an `Error` from this function with a custom validation message                                     |
| afterUpload              |                                                       | A method that is run right after a temporary upload has completed, `{ success: true, uuid }`                                                                                      |
| onChange                 |                                                       |                                                                                                                                                                                   |
| onIsReadyToSubmitChange  |                                                       | Refer to the ["Checking the upload state"](#content-checking-the-upload-state) section                                                                                                    |
